@@ -13,6 +13,7 @@ import time
 
 import boto3
 import requests
+import sentry_sdk
 from requests.exceptions import HTTPError
 
 from toolchest_client.api.auth import get_headers
@@ -395,6 +396,7 @@ class Query:
         """Checks for flag set by parent process to see if it should terminate self."""
         thread_status = self.thread_statuses.get(self.thread_name)
         if thread_status == ThreadStatus.INTERRUPTING:
+            sentry_sdk.set_tag('send_page', False)
             self._update_status_to_failed(
                 error_message="Terminating due to failure in sibling thread or parent process",
                 force_raise=False,
